==> edge-login-ui-rn-3.3.1.tgz: package/lib/components/themed/ThemedScene.js <==
import * as React from 'react';
import { SafeAreaView, Text, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome5';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
import { DividerLine } from './DividerLine';
export function ThemedScene(props) {
    const { backButtonText, branding = {}, children, onBack, onSkip, paddingRem, title, noUnderline = false } = props;
    const { parentButton } = branding;
    const theme = useTheme();
    const styles = getStyles(theme);
    const hasHeader = onBack != null || onSkip != null || title != null || parentButton != null;
    const handleParentButtonPress = useHandler(() => {
        if (parentButton != null)
            parentButton.callback();
    });
    const containerStyle = Object.assign({ flex: 1 }, sidesToPadding(mapSides(fixSides(paddingRem, 0.5), theme.rem)));
    return (React.createElement(SafeAreaView, { style: { flex: 1 } },
        !hasHeader ? null : (React.createElement(View, { style: styles.headerButtons },
            onBack == null ? null : (React.createElement(TouchableOpacity, { accessible: false, style: styles.leftButton, onPress: onBack },
                React.createElement(FontAwesome5, { accessible: true, testID: "headerLeftButton", name: "chevron-left", size: theme.rem(1), style: styles.buttonIcon }),
                backButtonText == null ? null : (React.createElement(Text, { accessible: true, style: styles.buttonText }, backButtonText)))),
            onSkip == null ? null : (React.createElement(TouchableOpacity, { accessible: true, testID: "headerRightButton", style: styles.rightButton, onPress: onSkip },
                React.createElement(Text, { style: styles.buttonText }, lstrings.skip))),
            parentButton == null || parentButton.text == null ? null : (React.createElement(TouchableOpacity, { accessible: true, style: styles.rightButton, onPress: handleParentButtonPress },
                React.createElement(Text, { style: parentButton.style || styles.buttonText }, parentButton.text))))),
        title == null ? null : (React.createElement(View, null,
            React.createElement(Text, { style: styles.titleText }, title))),
        !hasHeader || noUnderline ? null : React.createElement(DividerLine, { marginRem: [1, 1, 0] }),
        React.createElement(View, { style: containerStyle }, children)));
}
const getStyles = cacheStyles((theme) => ({
    headerButtons: {
        flexDirection: 'row',
        height: theme.rem(3)
    },
    leftButton: {
        alignItems: 'center',
        flexDirection: 'row',
        justifyContent: 'center',
        paddingHorizontal: theme.rem(1),
        minWidth: theme.rem(3),
        minHeight: theme.rem(3),
        position: 'absolute',
        left: 0,
        top: theme.rem(-1)
    },
    rightButton: {
        alignItems: 'center',
        flexDirection: 'row',
        justifyContent: 'center',
        paddingHorizontal: theme.rem(1),
        minWidth: theme.rem(3),
        minHeight: theme.rem(3),
        position: 'absolute',
        right: 0,
        top: theme.rem(-1)
    },
    buttonIcon: {
        color: theme.primaryText,
        paddingRight: theme.rem(0.5),
        height: theme.rem(1)
    },
    buttonText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1)
    },
    titleText: {
        color: theme.primaryText,
        fontSize: theme.rem(1.25),
        fontFamily: theme.fontFaceBold,
        marginHorizontal: theme.rem(1)
    }
}));

==> edge-login-ui-rn-3.3.3.tgz: package/lib/components/themed/ThemedScene.js <==
import * as React from 'react';
import { SafeAreaView, Text, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome5';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
import { DividerLine } from './DividerLine';
export function ThemedScene(props) {
    const { backButtonText, branding = {}, children, onBack, onSkip, paddingRem, title, noUnderline = false } = props;
    const { parentButton } = branding;
    const theme = useTheme();
    const styles = getStyles(theme);
    const hasHeader = onBack != null || onSkip != null || title != null || parentButton != null;
    const handleParentButtonPress = useHandler(() => {
        if (parentButton != null)
            parentButton.callback();
    });
    const containerStyle = Object.assign({ flex: 1 }, sidesToPadding(mapSides(fixSides(paddingRem, 0.5), theme.rem)));
    return (React.createElement(SafeAreaView, { style: { flex: 1 } },
        !hasHeader ? null : (React.createElement(View, { style: styles.headerButtons },
            onBack == null ? null : (React.createElement(TouchableOpacity, { accessible: false, style: styles.leftButton, onPress: onBack },
                React.createElement(FontAwesome5, { accessible: true, testID: "headerLeftButton", name: "chevron-left", size: theme.rem(1), style: styles.buttonIcon }),
                backButtonText == null ? null : (React.createElement(Text, { accessible: true, style: styles.buttonText }, backButtonText)))),
            onSkip == null ? null : (React.createElement(TouchableOpacity, { accessible: true, testID: "headerRightButton", style: styles.rightButton, onPress: onSkip },
                React.createElement(Text, { style: styles.buttonText }, lstrings.skip))),
            parentButton == null || parentButton.text == null ? null : (React.createElement(TouchableOpacity, { accessible: true, style: styles.rightButton, onPress: handleParentButtonPress },
                React.createElement(Text, { style: parentButton.style || styles.buttonText }, parentButton.text))))),
        title == null ? null : (React.createElement(View, null,
            React.createElement(Text, { style: styles.titleText }, title))),
        !hasHeader || noUnderline ? null : React.createElement(DividerLine, { marginRem: [1, 1, 0] }),
        React.createElement(View, { style: containerStyle }, children)));
}
const getStyles = cacheStyles((theme) => {
    const buttonHeight = theme.rem(4.5);
    return {
        headerButtons: {
            flexDirection: 'row',
            height: buttonHeight
        },
        leftButton: {
            alignItems: 'center',
            flexDirection: 'row',
            justifyContent: 'center',
            paddingHorizontal: theme.rem(1),
            minWidth: theme.rem(3),
            minHeight: buttonHeight,
            position: 'absolute',
            left: 0,
            top: theme.rem(-1)
        },
        rightButton: {
            alignItems: 'center',
            flexDirection: 'row',
            justifyContent: 'center',
            paddingHorizontal: theme.rem(1),
            minWidth: theme.rem(3),
            minHeight: buttonHeight,
            position: 'absolute',
            right: 0,
            top: theme.rem(-1)
        },
        buttonIcon: {
            color: theme.primaryText,
            paddingRight: theme.rem(0.5),
            height: theme.rem(1)
        },
        buttonText: {
            color: theme.primaryText,
            fontFamily: theme.fontFaceDefault,
            fontSize: theme.rem(1)
        },
        titleText: {
            color: theme.primaryText,
            fontSize: theme.rem(1.25),
            fontFamily: theme.fontFaceBold,
            marginHorizontal: theme.rem(1)
        }
    };
});
